package com.joshvm.demo;

import java.io.IOException;
import java.io.InputStream;

import javax.microedition.io.Connector;
import javax.microedition.io.file.FileConnection;

import org.joshvm.remote.CameraController;
import org.joshvm.remote.CameraController.Request;
import org.joshvm.remote.CameraController.Request.Builder;
import org.joshvm.remote.RequestListener;

/**
 * RTSP实例：通过RTSP远程控制拍照、拍视频，把形成的文件存到sd卡
 * 前提：需要一台支持RTSP的网络摄像头
 */
public class RtspDemo {
private static String url = "rtsp://admin:josh2017@192.168.1.64:554/h264/ch1/main/av_stream";
	
	public static void main(String[] args) {
		
		System.out.println("Start Rtsp Demo...");
		
		testCapturePicture();
	}

	private static void checkRequestResult(Request request) {
		FileConnection con = null;
		InputStream is = null;

		System.out.println("check file: " + request.getOutputFile());
		try {
			con = (FileConnection) Connector.open("file://" + request.getOutputFile());
			if (!con.exists()) {
				System.out.println("no file exist.");
				return;
			} else {
				System.out.println("file size: " + con.fileSize());

				is = con.openInputStream();
				byte buf[] = new byte[1024];
				int len = 0;
				int total = 0;
				while ((len = is.read(buf, 0, buf.length)) >= 0) {
					total += len;

				}
				System.out.println("total read: " + total);
				// con.delete();
			}
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			if (is != null) {
				try {
					is.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
			if (con != null) {
				try {
					con.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
	}

	public static void testCapture(final Request request) {
		CameraController controller = null;
		try {
			controller = CameraController.getController();

			// set listener
			controller.setRequestListener(new RequestListener() {
				public void onRequestResult(int requestId, int result) {
					System.out.println("recv request result. reqId: " + requestId + ", result: " + result);
					synchronized (request) {
						request.notify();
					}
				}
			});
			controller.capture(request);
			synchronized (request) {
				request.wait();
			}
			checkRequestResult(request);
		} catch (Exception e) {
			e.printStackTrace();
		}

		if (controller != null) {
			controller.setRequestListener(null);
			try {
				controller.release();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
	}

	public static void testCapturePicture() {
		final String outputFile = "/sdcard/test1.png";

		// create request by builder
		Builder builder = new Builder(Request.TYPE_TAKE_PICTURE);
		builder.setUrl(url).setOutputFile(outputFile);
		final Request request = builder.build();
		System.out.println("picture request id is: " + request.getId());

		testCapture(request);
	}

	public static void testCaptureVideo() {
		final String outputFile = "/sdcard/test.avi";

		// create request by builder
		Builder builder = new Builder(Request.TYPE_TAKE_VIDEO);
		builder.setUrl(url).setOutputFile(outputFile).setDuration(5000);
		Request request = builder.build();
		System.out.println("video request id is: " + request.getId());

		testCapture(request);
	}
}
